/**
 * Extend the basic ActorSheet with some very simple modifications
 * @extends {ActorSheet}
 */

import { SoSUtility } from "./sos-utility.js";

/* -------------------------------------------- */
export class SoSActorSheet extends ActorSheet {

  /** @override */
  static get defaultOptions() {
    return mergeObject(super.defaultOptions, {
      classes: ["sos", "sheet", "actor"],
      template: "systems/foundryvtt-shadows-over-sol/templates/actor-sheet.html",
      width: 640,
      //height: 720,
      tabs: [{ navSelector: ".sheet-tabs", contentSelector: ".sheet-body", initial: "stats" }],
      dragDrop: [{ dragSelector: ".item-list .item", dropSelector: null }],
      editStatSkill: false
    });
  }

  /* -------------------------------------------- */
  getData() {
    let data = super.getData();
    
    data.data.edgecard = this.actor.getEdgesCard();
    data.data.editStatSkill =  this.options.editStatSkill;
    console.log("stats", data);
    //data.stats  = duplicate(this.actor.stats);
    //data.scores = duplicate(this.actor.scores);

    return data;
  }

  /* -------------------------------------------- */
  async _onDrop(event) {
    super._onDrop(event);
  }

  /* -------------------------------------------- */
  /** @override */
  activateListeners(html) {
    super.activateListeners(html);

    //HtmlUtility._showControlWhen($(".gm-only"), game.user.isGM);

    // Everything below here is only needed if the sheet is editable
    if (!this.options.editable) return;

    // Update Inventory Item
    html.find('.item-edit').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      const item = this.actor.getOwnedItem(li.data("item-id"));
      item.sheet.render(true);
    });

    // Delete Inventory Item
    html.find('.item-delete').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      RdDUtility.confirmerSuppression(this, li);
    });

    html.find('.stat-label a').click((event) => {
      let statName = event.currentTarget.attributes.name.value;
      this.actor.rollStat(statName);
    });
    html.find('.edge-draw').click((event) => {
      this.actor.resetDeck();
      this.render(true);
    });
    html.find('.lock-unlock-sheet').click((event) => {
      this.options.editStatSkill = !this.options.editStatSkill;
      this.render(true);
    });    
  }

  /* -------------------------------------------- */
  /** @override */
  setPosition(options = {}) {
    const position = super.setPosition(options);
    const sheetBody = this.element.find(".sheet-body");
    const bodyHeight = position.height - 192;
    sheetBody.css("height", bodyHeight);
    return position;
  }


  /* -------------------------------------------- */
  /** @override */
  _updateObject(event, formData) {
    // Update the Actor
    return this.object.update(formData);
  }
}
